"""Constants for the Apple TV integration."""

DOMAIN = "apple_tv"

CONF_IDENTIFIER = "identifier"
CONF_CREDENTIALS = "credentials"
CONF_CREDENTIALS_MRP = "mrp"
CONF_CREDENTIALS_DMAP = "dmap"
CONF_CREDENTIALS_AIRPLAY = "airplay"

CONF_START_OFF = "start_off"
