"""Constants for the flo integration."""
import logging

LOGGER = logging.getLogger(__package__)

CLIENT = "client"
DOMAIN = "flo"
FLO_HOME = "home"
FLO_AWAY = "away"
FLO_SLEEP = "sleep"
FLO_MODES = [FLO_HOME, FLO_AWAY, FLO_SLEEP]
