"""Adds constants for Trafikverket Weather integration."""

DOMAIN = "trafikverket_weatherstation"
CONF_STATION = "station"
PLATFORMS = ["sensor"]
ATTRIBUTION = "Data provided by Trafikverket"
ATTR_MEASURE_TIME = "measure_time"
ATTR_ACTIVE = "active"
