"""Constants for the Yamaha component."""
DOMAIN = "yamaha"
CURSOR_TYPE_DOWN = "down"
CURSOR_TYPE_LEFT = "left"
CURSOR_TYPE_RETURN = "return"
CURSOR_TYPE_RIGHT = "right"
CURSOR_TYPE_SELECT = "select"
CURSOR_TYPE_UP = "up"
SERVICE_ENABLE_OUTPUT = "enable_output"
SERVICE_MENU_CURSOR = "menu_cursor"
SERVICE_SELECT_SCENE = "select_scene"
