"""Integration shared constants."""
import logging

DATA_VLC = "vlc"
DATA_AVAILABLE = "available"
DEFAULT_NAME = "VLC-TELNET"
DEFAULT_PORT = 4212
DOMAIN = "vlc_telnet"
LOGGER = logging.getLogger(__package__)
